RDFCalendar.Store

Package RDFCalendar :: Module Store |
[show private | hide private]
[frames | no frames]

## Module RDFCalendar.Store

    Storage of nodes according to RDFCalendar conventions.

    Copyright (C) 2005, 2006, 2007 Paul Boddie <paul@boddie.org.uk>

    This program is free software; you can redistribute it and/or modify it under
    the terms of the GNU Lesser General Public License as published by the Free
    Software Foundation; either version 3 of the License, or (at your option) any
    later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
    FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
    details.

    You should have received a copy of the GNU Lesser General Public License along
    with this program.  If not, see <http://www.gnu.org/licenses/>.

Classes
`DebugStore` | A class displaying store operations.
`FreeBusyRequest` | A record of free/busy request information.
`Store` | A wrapper around a data store, providing convenient access for parsers and writers.

Function Summary
| ``open`(store_name, store_type, context, **kw)` Open the store with the given 'store_name' of the given 'store_type', providing an optional 'context' where supported.

Function Details

### open(store_name, store_type, context=None, **kw)
    Open the store with the given 'store_name' of the given 'store_type',
    providing an optional 'context' where supported.

Generated by Epydoc 2.1 on Tue Sep 18 23:33:17 2007 | http://epydoc.sf.net